@@ -752,16 +752,20 @@ static void fsaa_update_received(GtkObject *object,
     CtkEventStruct *event_struct;
     CtkMultisample *ctk_multisample;
     GtkRange *range;
+    gint val;
 
     event_struct = (CtkEventStruct *) arg1;
     ctk_multisample = CTK_MULTISAMPLE(user_data);
     range = GTK_RANGE(ctk_multisample->fsaa_scale);
 
+    val = map_nv_ctrl_fsaa_value_to_slider(ctk_multisample,
+                                           event_struct->value);
+
     g_signal_handlers_block_by_func(G_OBJECT(range),
                                     G_CALLBACK(fsaa_value_changed),
                                     (gpointer) ctk_multisample);
     
-    gtk_range_set_value(range, event_struct->value);
+    gtk_range_set_value(range, val);
     
     g_signal_handlers_unblock_by_func(G_OBJECT(range),
                                       G_CALLBACK(fsaa_value_changed),
@@ -1185,9 +1189,9 @@ GtkTextBuffer *ctk_multisample_create_help(GtkTextTagTable *table,
                       "expense of some performance.");
 
         ctk_help_para(b, &i, "You can also configure Anisotropic filtering "
-                      "using the __GL_DEFAULT_LOG_ANISO environment varible "
+                      "using the __GL_LOG_MAX_ANISO environment varible "
                       "(see the README for details).  The "
-                      "__GL_DEFAULT_LOG_ANISO environment variable overrides "
+                      "__GL_LOG_MAX_ANISO environment variable overrides "
                       "the value in nvidia-settings.");
         
         ctk_help_term(b, &i, "Override Application Setting");
